# rss-transmission

[![Build Status](https://travis-ci.org/helloqiu/rss-transmission.svg?branch=master)](https://travis-ci.org/helloqiu/rss-transmission)
[![codecov](https://codecov.io/gh/helloqiu/rss-transmission/branch/master/graph/badge.svg)](https://codecov.io/gh/helloqiu/rss-transmission)

Rss for transmission.
